@@ -58,7 +58,7 @@
 /* #undef WITH_MEDIA_FOUNDATION */
 /* #undef WITH_MEDIACODEC */
 
-/* #undef WITH_VAAPI */
+#define WITH_VAAPI
 
 #define WITH_CHANNELS
 #define WITH_CLIENT_CHANNELS
